@@ -19,12 +19,10 @@ if not os.path.exists(meta["audioldm"]["path"]):
     os.makedirs(os.path.dirname(meta["audioldm"]["path"]), exist_ok=True)
     print("Downloading the main structure of audioldm")
 
-    urllib.request.urlretrieve(
-        meta["audioldm"]["url"], meta["audioldm"]["path"]
-    )
+    urllib.request.urlretrieve(meta["audioldm"]["url"], meta["audioldm"]["path"])
     print(
         "Weights downloaded in: {} Size: {}".format(
             meta["audioldm"]["path"],
             os.path.getsize(meta["audioldm"]["path"]),
         )
-    )
\ No newline at end of file
+    )
